Welcome to django-authopenid’s documentation! — django-authopenid v1.0 documentation

### Navigation

- index
- next |
- django-authopenid v1.0 documentation »

# Welcome to django-authopenid’s documentation!

Everything you need to know about django-authopenid

django-authopenid is a Django application that allow you to authenticate your users while using the django auth contrib.

This application allow a user to connect to you website with :

> - legacy account : username/password
> - openid url

Idee is having workflow to integrate openid and _legacy_ authentification.

If the user connect with an openid he could associate it with its legaccy account or just create a new django account. When the user is connected you could manage him like you usually do with auth contrib or django-registration which is the default.

Made by Enki Multimedia for one of our project and we decided to make it public.

Contents:

- Installation
- Requirements
- Getting Started
- Basic use
- Templates used by django-authopenid
- How it works
- Where to go from here
- Views reference
- Models reference
  - User association
  - Openid store
- Forms reference
- Changes
  - version 1.0

- Follow development on Bitbucket.
- Report bugs, report features and browse the source through Tracker.

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- django-authopenid v1.0 documentation »